==> jc-1.4.0.tar.gz: javax/security/sasl/RealmCallback.h <==
// public class javax.security.sasl.RealmCallback

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 89cc839ce5e99ecf javax_security_auth_callback_TextInputCallback
// @dep_class 7481844d9d66b085 javax_security_sasl_RealmCallback

// header file dependencies
// @dep_header javax_security_auth_callback_TextInputCallback

#include "javax/security/auth/callback/TextInputCallback.h"

#ifndef _JC_javax_security_sasl_RealmCallback_H_
#define _JC_javax_security_sasl_RealmCallback_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_security_sasl_RealmCallback$sub_refs	_jc_javax_security_sasl_RealmCallback$sub_refs;
typedef struct _jc_javax_security_sasl_RealmCallback$sub_nonrefs	_jc_javax_security_sasl_RealmCallback$sub_nonrefs;
typedef struct _jc_javax_security_sasl_RealmCallback$refs	_jc_javax_security_sasl_RealmCallback$refs;
typedef struct _jc_javax_security_sasl_RealmCallback$nonrefs	_jc_javax_security_sasl_RealmCallback$nonrefs;
typedef struct _jc_javax_security_sasl_RealmCallback$object	_jc_javax_security_sasl_RealmCallback$object;

typedef const struct _jc_javax_security_sasl_RealmCallback$vmethods	_jc_javax_security_sasl_RealmCallback$vmethods;
typedef const struct _jc_javax_security_sasl_RealmCallback$vtable	_jc_javax_security_sasl_RealmCallback$vtable;
typedef const struct _jc_javax_security_sasl_RealmCallback$vtype	_jc_javax_security_sasl_RealmCallback$vtype;

// Constructors
extern void _jc_javax_security_sasl_RealmCallback$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_security_sasl_RealmCallback$object *, struct _jc_java_lang_String$object *);
extern void _jc_javax_security_sasl_RealmCallback$method$_init$a34354cd9552963f(_jc_env *, struct _jc_javax_security_sasl_RealmCallback$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_javax_security_sasl_RealmCallback$vmethods {
};

// Vtable
struct _jc_javax_security_sasl_RealmCallback$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_security_auth_callback_TextInputCallback$vmethods	javax_security_auth_callback_TextInputCallback;
	_jc_javax_security_sasl_RealmCallback$vmethods	javax_security_sasl_RealmCallback;
};

// Vtype
struct _jc_javax_security_sasl_RealmCallback$vtype {
	_jc_type			type;
	_jc_javax_security_sasl_RealmCallback$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_security_sasl_RealmCallback$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_security_sasl_RealmCallback$refs {
    _jc_javax_security_sasl_RealmCallback$sub_refs	javax_security_sasl_RealmCallback;
    _jc_javax_security_auth_callback_TextInputCallback$sub_refs	javax_security_auth_callback_TextInputCallback;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_security_sasl_RealmCallback$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_security_sasl_RealmCallback$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_security_auth_callback_TextInputCallback$sub_nonrefs	javax_security_auth_callback_TextInputCallback;
    _jc_javax_security_sasl_RealmCallback$sub_nonrefs	javax_security_sasl_RealmCallback;
};

// Object instance structure
struct _jc_javax_security_sasl_RealmCallback$object {
	_jc_javax_security_sasl_RealmCallback$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_security_sasl_RealmCallback$vtype	*vtype;
	_jc_javax_security_sasl_RealmCallback$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_security_sasl_RealmCallback$vtype _jc_javax_security_sasl_RealmCallback$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_security_sasl_RealmCallback, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_security_sasl_RealmCallback$class_object;

#endif	/* _JC_javax_security_sasl_RealmCallback_H_ */

==> jc-1.4.6.tar.gz: javax/security/sasl/RealmCallback.h <==
// public class javax.security.sasl.RealmCallback

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 89cc839ce5e99ecf javax_security_auth_callback_TextInputCallback
// @dep_class 7481844d9d66b085 javax_security_sasl_RealmCallback

// header file dependencies
// @dep_header javax_security_auth_callback_TextInputCallback

#include "javax/security/auth/callback/TextInputCallback.h"

#ifndef _JC_javax_security_sasl_RealmCallback_H_
#define _JC_javax_security_sasl_RealmCallback_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_security_sasl_RealmCallback$sub_refs	_jc_javax_security_sasl_RealmCallback$sub_refs;
typedef struct _jc_javax_security_sasl_RealmCallback$sub_nonrefs	_jc_javax_security_sasl_RealmCallback$sub_nonrefs;
typedef struct _jc_javax_security_sasl_RealmCallback$refs	_jc_javax_security_sasl_RealmCallback$refs;
typedef struct _jc_javax_security_sasl_RealmCallback$nonrefs	_jc_javax_security_sasl_RealmCallback$nonrefs;
typedef struct _jc_javax_security_sasl_RealmCallback$object	_jc_javax_security_sasl_RealmCallback$object;

typedef const struct _jc_javax_security_sasl_RealmCallback$vmethods	_jc_javax_security_sasl_RealmCallback$vmethods;
typedef const struct _jc_javax_security_sasl_RealmCallback$vtable	_jc_javax_security_sasl_RealmCallback$vtable;
typedef const struct _jc_javax_security_sasl_RealmCallback$vtype	_jc_javax_security_sasl_RealmCallback$vtype;

// Constructors
extern void _jc_javax_security_sasl_RealmCallback$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_security_sasl_RealmCallback$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_javax_security_sasl_RealmCallback$method$_init$a34354cd9552963f(_jc_env *, struct _jc_javax_security_sasl_RealmCallback$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_security_sasl_RealmCallback$vmethods {
};

// Vtable
struct _jc_javax_security_sasl_RealmCallback$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_security_auth_callback_TextInputCallback$vmethods	javax_security_auth_callback_TextInputCallback;
	_jc_javax_security_sasl_RealmCallback$vmethods	javax_security_sasl_RealmCallback;
};

// Vtype
struct _jc_javax_security_sasl_RealmCallback$vtype {
	_jc_type			type;
	_jc_javax_security_sasl_RealmCallback$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_security_sasl_RealmCallback$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_security_sasl_RealmCallback$refs {
    _jc_javax_security_sasl_RealmCallback$sub_refs	javax_security_sasl_RealmCallback;
    _jc_javax_security_auth_callback_TextInputCallback$sub_refs	javax_security_auth_callback_TextInputCallback;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_security_sasl_RealmCallback$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_security_sasl_RealmCallback$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_security_auth_callback_TextInputCallback$sub_nonrefs	javax_security_auth_callback_TextInputCallback;
    _jc_javax_security_sasl_RealmCallback$sub_nonrefs	javax_security_sasl_RealmCallback;
};

// Object instance structure
struct _jc_javax_security_sasl_RealmCallback$object {
	_jc_javax_security_sasl_RealmCallback$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_security_sasl_RealmCallback$vtype	*vtype;
	_jc_javax_security_sasl_RealmCallback$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_security_sasl_RealmCallback$vtype _jc_javax_security_sasl_RealmCallback$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_security_sasl_RealmCallback, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_security_sasl_RealmCallback$class_object;

#endif	/* _JC_javax_security_sasl_RealmCallback_H_ */
